@@ -127,7 +127,7 @@ class ArteConcert(QObject):
                 lgg.warning("Reason: %s" % why)
 
     def get_update(self):
-        url = 'http://www.oqapy.eu/releases/concerts_%s.jsn' % self.lang
+        url = 'http://www.oqapy.eu/htdocs/releases/concerts_%s.jsn' % self.lang
         req = urllib.request.Request(url, data=None,
                                      headers={"User-Agent": USER_AGENT})
         lgg.info('Get update ...')
