@@ -111,7 +111,7 @@ class ArteTV(QObject):
         Args:
         number -- number of videos in arte+7, unusued
         """
-        url = 'http://www.oqapy.eu/releases/artetv_videos_%s.jsn' % self.lang
+        url = 'http://www.oqapy.eu/htdocs/releases/artetv_videos_%s.jsn' % self.lang
         update = self.get_update(url)
         is_videos = False
         try:
@@ -1247,7 +1247,7 @@ class SerialParser(HTMLParser):
     """Parser general"""
     def __init__(self):
         super().__init__()
-        videos = []
+        self.videos = []
         self.in_item = False
         self.in_title = False
         self.in_title1 = False
