@@ -144,20 +144,21 @@ class Downloader(QObject):
             return
 
         # TODO check free space (artetv line 975)
-        lgg.info('Start download %s file size: %s' 
-                    %(item.fname, self.file_size))
+
         lgg.info('URL: %s' % video[0])
         self.merged_filename = self.get_final_file_name(item.idx)
         self.video_title = item.fname
-        Thread(target=loader.download).start()
         audio = self.files_needed[1]
         loader1 = Loader()
         if not self.initiate_loader(loader1, audio[0], audio[1]):
             return
 
-        lgg.info('Start download audio file size: %s' % self.file_size)
+        lgg.info('Start download audio %s size: %s' 
+                    %(item.fname, loader1.size))
         Thread(target=loader1.download).start()
-
+        lgg.info('Start download video %s size: %s' 
+                    %(item.fname, loader.size))
+        Thread(target=loader.download).start()
         self.loaders = [loader, loader1]
 
         if len(self.files_needed) > 2:
